Stan Math Library: stan/math/fwd/core/operator_addition.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_addition.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_CORE_OPERATOR_ADDITION_HPP
2 #define STAN_MATH_FWD_CORE_OPERATOR_ADDITION_HPP
3
4 #include <stan/math/fwd/core/fvar.hpp>
5
6 namespace stan {
7
8 namespace math {
9
10 template <typename T>
11 inline
12 fvar<T>
13 operator+(const fvar<T>& x1, const fvar<T>& x2) {
14 return fvar<T>(x1.val_ + x2.val_, x1.d_ + x2.d_);
15 }
16
17 template <typename T>
18 inline
19 fvar<T>
20 operator+(const double x1, const fvar<T>& x2) {
21 return fvar<T>(x1 + x2.val_, x2.d_);
22 }
23
24 template <typename T>
25 inline
26 fvar<T>
27 operator+(const fvar<T>& x1, const double x2) {
28 return fvar<T>(x1.val_ + x2, x1.d_);
29 }
30 }
31 }
32 #endif
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
fvar.hpp
stan::math::operator+
fvar< T > operator+(const fvar< T > &x1, const fvar< T > &x2)
Definition: operator_addition.hpp:13
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.